#ifndef INODEWIN_H
#define INODEWIN_H

extern void   magic_scanner();
extern int    magic_need_scan;

#endif/* ------------ End of file -------------- */

